use dioxus::prelude::*;

use crate::TransactionCard;

/// Home Page
#[component]
pub fn Home() -> Element {
    let min = use_resource(move || async move { crate::api::API::get_items_under_min().await });
    let expired = use_resource(move || async move { crate::api::API::get_expired_items().await });
    let global = use_resource(move || async move { crate::api::API::get_global_item_stat().await });

    rsx! {
            div {
                h1 { "Home" },
                div {
                    id: "column",

                    match &*global.read_unchecked() {
                        Some(resp) => rsx! {
                            div {
                        id: "card",
                        p { {format!("Items: {}", resp.item_count)} }
                        p { {format!("Inventory: {}", resp.total_transactions)} }
                        p { {format!("Price: {}", resp.total_price)} }
                    }
                        },
                        None => rsx! {
                            div { "Loading dogs..." }
                        },
                    },

                    if let Some(min) = &*min.read_unchecked() {
                        if !min.is_empty() {
                            h1 { "Items under Minimum" },
                            for item in min {
                                p { {format!("{} under minimum. Needs {} more.", item.item_variant, item.need)} }
                            }
                        }
                    }

                    if let Some(expired) = &*expired.read_unchecked() {
                        if !expired.is_empty() {
                            h1 { "Expired Items" },
                            for item in expired {
                                TransactionCard { t: item.clone() }
                            }
                        }
                    }
            }
        }
    }
}
