use dioxus::prelude::*;
use std::collections::HashMap;

#[component]
pub fn LocationsPage() -> Element {
    let api = crate::API.read();
    let locations = use_signal(|| api.as_ref().unwrap().get_locations().clone());

    let roots: Vec<String> = get_root_locations(&*locations.read());

    rsx! {
        h1 { "Locations" },

        for l in &roots {
            LocationTreeTile { location: l.clone(), locations }
        }
    }
}

pub fn get_root_locations(locations: &HashMap<String, crate::api::Location>) -> Vec<String> {
    let mut ret = Vec::new();

    for (_, v) in locations {
        if v.parent.is_none() {
            ret.push(v.id.clone());
        }
    }

    ret
}

pub fn get_children_of_loc(
    loc: String,
    locations: &HashMap<String, crate::api::Location>,
) -> Vec<String> {
    let mut ret = Vec::new();

    for (_, v) in locations {
        if let Some(parent) = &v.parent {
            if *parent == loc {
                ret.push(v.id.clone());
            }
        }
    }

    ret
}

#[component]
pub fn LocationTreeTile(
    location: String,
    locations: Signal<HashMap<String, crate::api::Location>>,
) -> Element {
    let mut open = use_signal(|| false);

    // TODO
    let children = get_children_of_loc(location.clone(), &*locations.read());

    rsx! {
        p { {location} }
        button {
            onclick: move |_| { open.set(true); },
            "Expand"
        }

        if *open.read() {
            for loc in &children {
                LocationTreeTile { location: loc.clone(), locations }
            }
        }
    }
}

#[component]
pub fn LocationPage(location: String) -> Element {
    let mut recursive = use_signal(|| true);

    rsx! {
        h1 { {location} }

        div {
            id: "location-info",
            p { "Info" }
        }

        input {
            r#type: "checkbox",
            value: !*recursive.read(),
            onclick: move |_| {
                let val = *recursive.read();
                recursive.set(!val);
            },
            "Show only entries matching this location"
        }

        // Transaction List

    }
}
